<?php

/**
 * @file
 * Imagepin form alteration implementations.
 */

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Drupal\Component\Serialization\Json;

/**
 * Adds the link to the pin form to an image form element.
 *
 * See imagepin_field_widget_form_alter()
 *
 * @param array &$element
 *   The element array.
 * @param \Drupal\Core\Form\FormStateInterface $form_state
 *   The form state.
 * @param array $context
 *   The context array.
 */
function imagepin_add_link_to_form_element(array &$element, FormStateInterface $form_state, array $context) {

  $field_name = $context['items']->getName();
  $entity = $context['items']->getEntity();
  $entity_type = $entity->getEntityTypeId();
  $bundle = $entity->bundle();
  $enabled_view_modes = \Drupal::service('entity_display.repository')
    ->getViewModeOptionsByBundle($entity_type, $bundle);
  $view_storage = \Drupal::entityTypeManager()->getStorage('entity_view_display');

  foreach (array_keys($enabled_view_modes) as $view_mode) {
    $content = $view_storage->load($entity_type . '.' . $bundle . '.' . $view_mode)->get('content');
    if (empty($content[$field_name]['third_party_settings']['imagepin']['pinable'])
    || (empty($content[$field_name]['settings']['image_style']) && empty($content[$field_name]['settings']['responsive_image_style']))) {
      continue;
    }
    $arguments = [
      'image_fid' => reset($element['#default_value']['fids']),
      'field_name' => $field_name,
      'entity_type' => $entity_type,
      'bundle' => $bundle,
      'language' => $entity->language()->getId(),
      'id' => 'new',
    ];
    if (!$entity->isNew()) {
      $arguments['id'] = $entity->id();
    }
    $element['imagepin'] = [
      '#prefix' => '<div>',
      '#suffix' => '</div>',
      '#weight' => 100,
      '#type' => 'link',
      '#title' => t('Pin widgets on this image'),
      '#url' => Url::fromRoute('imagepin.pin_widgets', $arguments),
      '#attributes' => [
        'class' => ['use-ajax', 'button', 'button--small'],
        'data-dialog-type' => 'modal',
        'data-dialog-options' => Json::encode(['width' => '90%']),
      ],
    ];
    break;
  }
}
